@@ -2,9 +2,9 @@
 /**
  * Horde_CLI:: API for basic command-line functionality/checks.
  *
- * $Horde: framework/CLI/CLI.php,v 1.42.6.24 2008/07/16 17:40:46 jan Exp $
+ * $Horde: framework/CLI/CLI.php,v 1.42.6.28 2009/11/13 14:28:40 mrubinsk Exp $
  *
- * Copyright 2003-2008 The Horde Project (http://www.horde.org/)
+ * Copyright 2003-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -171,6 +171,10 @@ class Horde_CLI {
             $this->_blue_start   = '<span style="color:blue">';
             $this->_red_end = $this->_green_end = $this->_yellow_end = $this->_blue_end = '</span>';
         }
+
+        if ($this->_console) {
+            register_shutdown_function(array($this, '_shutdown'));
+        }
     }
 
     /**
@@ -429,4 +433,12 @@ class Horde_CLI {
         }
     }
 
+    /**
+     * Destroys any session on script end.
+     */
+    function _shutdown()
+    {
+        @session_destroy();
+    }
+
 }
