@@ -3,9 +3,9 @@
  * Class for auto-generating the preferences user interface and
  * processing the forms.
  *
- * $Horde: framework/Prefs/Prefs/UI.php,v 1.63.2.15 2006/01/12 22:25:14 jan Exp $
+ * $Horde: framework/Prefs/Prefs/UI.php,v 1.63.2.26 2010/09/27 10:10:05 jan Exp $
  *
- * Copyright 2001-2006 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
@@ -67,7 +67,11 @@ class Prefs_UI {
         /* Run through the action handlers */
         if (Util::getPost('actionID') == 'update_prefs') {
             if (isset($group) && Prefs_UI::groupIsEditable($group)) {
-                $updated = false;
+                $result = Horde::checkRequestToken('horde.prefs', Util::getFormData('horde_prefs_token'));
+                if (is_a($result, 'PEAR_Error')) {
+                    $notification->push($result, 'horde.error');
+                    return $updated;
+                }
 
                 foreach ($prefGroups[$group]['members'] as $pref) {
                     if (!$prefs->isLocked($pref) ||
@@ -120,9 +124,9 @@ class Prefs_UI {
 
                         case 'number':
                             $num = Util::getPost($pref);
-                            if (intval($num) != $num) {
+                            if ((string)(double)$num !== $num) {
                                 $notification->push(_("This value must be a number."), 'horde.error');
-                            } elseif ($num == 0) {
+                            } elseif (empty($num)) {
                                 $notification->push(_("This number must be at least one."), 'horde.error');
                             } else {
                                 $updated = $updated | $save->setValue($pref, $num);
@@ -134,6 +138,28 @@ class Prefs_UI {
                             $updated = $updated | $save->setValue($pref, isset($val) ? 1 : 0);
                             break;
 
+                        case 'alarm':
+                            require_once 'Horde/Alarm.php';
+                            $methods = Horde_Alarm::notificationMethods();
+                            $value = array();
+                            foreach (Util::getPost($pref, array()) as $method) {
+                                $value[$method] = array();
+                                if (!empty($methods[$method])) {
+                                    foreach (array_keys($methods[$method]) as $param) {
+                                        $value[$method][$param] = Util::getPost($pref . '_' . $param, '');
+                                        if (is_array($methods[$method][$param]) &&
+                                            $methods[$method][$param]['required'] &&
+                                            $value[$method][$param] === '') {
+                                            $notification->push(sprintf(_("You must provide a setting for \"%s\"."), $methods[$method][$param]['desc']), 'horde.error');
+                                            $updated = false;
+                                            break 3;
+                                        }
+                                    }
+                                }
+                            }
+                            $updated = $updated | $save->setValue($pref, serialize($value));
+                            break;
+
                         case 'special':
                             /* Code for special elements must be
                              * written specifically for each
@@ -146,6 +172,14 @@ class Prefs_UI {
                     }
                 }
 
+                if (is_callable(array($save, 'verify'))) {
+                    $result = $save->verify();
+                    if (is_a($result, 'PEAR_Error')) {
+                        $notification->push($result, 'horde.error');
+                        $updated = false;
+                    }
+                }
+
                 if ($updated) {
                     if (function_exists('prefs_callback')) {
                         prefs_callback();
@@ -167,9 +201,11 @@ class Prefs_UI {
      * Generate the UI for the preferences interface, either for a
      * specific group, or the group selection interface.
      *
-     * @param string $group  The group to generate the UI for.
+     * @param string $group   The group to generate the UI for.
+     * @param boolean $chunk  Whether to only return the body part (since
+     *                        Horde 3.2.).
      */
-    function generateUI($group = null)
+    function generateUI($group = null, $chunk = false)
     {
         global $browser, $conf, $prefs, $prefGroups, $_prefs, $registry, $app;
 
@@ -178,20 +214,39 @@ class Prefs_UI {
             $GLOBALS['notification']->push(_("There are no options available."), 'horde.message');
         }
 
-        /* Show the header. */
-        Prefs_UI::generateHeader($group);
-
         /* Assign variables to hold select lists. */
         if (!$prefs->isLocked('language')) {
             $GLOBALS['language_options'] = $GLOBALS['nls']['languages'];
             array_unshift($GLOBALS['language_options'], _("Default"));
         }
 
-        if (!empty($group) && Prefs_UI::groupIsEditable($group)) {
+        $columns = array();
+        $in_group = (!empty($group) && Prefs_UI::groupIsEditable($group) && !empty($prefGroups[$group]['members']));
+
+        /* We need to do this check up here because it is possible that
+         * we will generate a notification object, which is handled by
+         * generateHeader. */
+        if (!$in_group && is_array($prefGroups)) {
+            foreach ($prefGroups as $key => $val) {
+                if (Prefs_UI::groupIsEditable($key)) {
+                    $col = $val['column'];
+                    unset($val['column']);
+                    $columns[$col][$key] = $val;
+                }
+            }
+            if (!count($columns)) {
+                $GLOBALS['notification']->push(_("There are no options available."), 'horde.message');
+            }
+        }
+
+        Prefs_UI::generateHeader($group, $chunk);
+
+        if ($in_group) {
             foreach ($prefGroups[$group]['members'] as $pref) {
                 if (!$prefs->isLocked($pref)) {
                     /* Get the help link. */
                     if (!empty($_prefs[$pref]['help'])) {
+                        require_once 'Horde/Help.php';
                         $helplink = Help::link(!empty($_prefs[$pref]['shared']) ? 'horde' : $registry->getApp(), $_prefs[$pref]['help']);
                     } else {
                         $helplink = null;
@@ -212,22 +267,8 @@ class Prefs_UI {
                 }
             }
             require $registry->get('templates', 'horde') . '/prefs/end.inc';
-        } else {
-            $span = 100;
-            $columns = array();
-            if (is_array($prefGroups)) {
-                foreach ($prefGroups as $group => $gvals) {
-                    if (Prefs_UI::groupIsEditable($group)) {
-                        $col = $gvals['column'];
-                        unset($gvals['column']);
-                        $columns[$col][$group] = $gvals;
-                    }
-                }
-                if (count($columns)) {
-                    $span = round(100 / count($columns));
-                }
-            }
-
+        } elseif (count($columns)) {
+            $span = round(100 / count($columns));
             require $registry->get('templates', 'horde') . '/prefs/overview.inc';
         }
     }
@@ -236,9 +277,11 @@ class Prefs_UI {
      * Generates the the full header of a preference screen including
      * menu and navigation bars.
      *
-     * @param string $group  The group to generate the header for.
+     * @param string $group   The group to generate the header for.
+     * @param boolean $chunk  Whether to only return the body part (since
+     *                        Horde 3.2.).
      */
-    function generateHeader($group = null)
+    function generateHeader($group = null, $chunk = false)
     {
         global $registry, $prefGroups, $app, $perms, $prefs, $notification;
 
@@ -246,21 +289,19 @@ class Prefs_UI {
         if ($group == 'identities' && !$prefs->isLocked('default_identity')) {
             $notification->push('newChoice()', 'javascript');
         }
-        require $registry->get('templates', $app) . '/common-header.inc';
-        if (is_callable(array($app, 'getMenu'))) {
-            $menu = call_user_func(array($app, 'getMenu'));
+        $GLOBALS['bodyId'] = 'services_prefs';
+        if (!$chunk) {
+            require $registry->get('templates', $app) . '/common-header.inc';
+            if (is_callable(array($app, 'getMenu'))) {
+                $menu = call_user_func(array($app, 'getMenu'));
+            }
             require $registry->get('templates', 'horde') . '/menu/menu.inc';
-        } else {
-            /* Use a default menu. */
-            require_once 'Horde/Menu.php';
-            $menu = &new Menu();
-            require $registry->get('templates', 'horde') . '/menu/menu.inc';
-        }
 
-        if (is_callable(array($app, 'status'))) {
-            call_user_func(array($app, 'status'));
-        } else {
-            $GLOBALS['notification']->notify(array('listeners' => 'status'));
+            if (is_callable(array($app, 'status'))) {
+                call_user_func(array($app, 'status'));
+            } else {
+                $GLOBALS['notification']->notify(array('listeners' => 'status'));
+            }
         }
 
         /* Get list of accessible applications. */
@@ -350,27 +391,13 @@ class Prefs_UI {
             return;
         }
 
-        echo '<ul><li>';
-        if (!empty($prefGroups[$previous]['url'])) {
-            echo Horde::link(Horde::applicationUrl($prefGroups[$previous]['url']),
-                             _("Previous options"));
-            echo '&lt;&lt; ' . $prefGroups[$previous]['label'];
-        } else {
-            echo Horde::link(Util::addParameter(Horde::url($registry->get('webroot', 'horde') . '/services/prefs.php'), array('group' => $previous, 'app' => $app)),
-                             _("Previous options"));
-            echo '&lt;&lt; ' . $prefGroups[$previous]['label'];
-        }
-        echo '</a>&nbsp;|&nbsp;';
-        if (!empty($prefGroups[$next]['url'])) {
-            echo Horde::link(Horde::applicationUrl($prefGroups[$next]['url']),
-                             _("Next options"));
-            echo $prefGroups[$next]['label'] . ' &gt;&gt;';
-        } else {
-            echo Horde::link(Util::addParameter(Horde::url($registry->get('webroot', 'horde') . '/services/prefs.php'), array('group' => $next, 'app' => $app)),
-                             _("Next options"));
-            echo $prefGroups[$next]['label'] . ' &gt;&gt;';
-        }
-        echo '</a></li></ul>';
+        echo '<ul><li>' .
+             Horde::link(Util::addParameter(Horde::url($registry->get('webroot', 'horde') . '/services/prefs.php'), array('app' => $app, 'group' => $previous), _("Previous options"))) .
+             '&lt;&lt; ' . $prefGroups[$previous]['label'] .
+             '</a>&nbsp;|&nbsp;' .
+             Horde::link(Util::addParameter(Horde::url($registry->get('webroot', 'horde') . '/services/prefs.php'), array('app' => $app, 'group' => $next), _("Next options"))) .
+             $prefGroups[$next]['label'] . ' &gt;&gt;' .
+             '</a></li></ul>';
     }
 
     /**
