@@ -1,4 +1,4 @@
--- $Horde: horde/scripts/sql/horde_datatree.mysql.sql,v 1.1.10.1 2006/05/22 21:27:33 jan Exp $
+-- $Horde: horde/scripts/sql/horde_datatree.mysql.sql,v 1.1.10.2 2007/12/20 15:03:03 jan Exp $
 
 CREATE TABLE horde_datatree (
        datatree_id INT NOT NULL,
@@ -16,6 +16,7 @@ CREATE INDEX datatree_datatree_name_idx ON horde_datatree (datatree_name);
 CREATE INDEX datatree_group_idx ON horde_datatree (group_uid);
 CREATE INDEX datatree_user_idx ON horde_datatree (user_uid);
 CREATE INDEX datatree_serialized_idx ON horde_datatree (datatree_serialized);
+CREATE INDEX datatree_parents_idx ON horde_datatree (datatree_parents);
 
 CREATE TABLE horde_datatree_attributes (
     datatree_id INT NOT NULL,
@@ -27,6 +28,4 @@ CREATE TABLE horde_datatree_attributes (
 CREATE INDEX datatree_attribute_idx ON horde_datatree_attributes (datatree_id);
 CREATE INDEX datatree_attribute_name_idx ON horde_datatree_attributes (attribute_name);
 CREATE INDEX datatree_attribute_key_idx ON horde_datatree_attributes (attribute_key);
-
-GRANT SELECT, INSERT, UPDATE, DELETE ON horde_datatree TO horde@localhost;
-GRANT SELECT, INSERT, UPDATE, DELETE ON horde_datatree_attributes TO horde@localhost;
+CREATE INDEX datatree_attribute_value_idx ON horde_datatree_attributes (attribute_value(255));
